# MST_BOOST_BASE
#---------------
#
#  SYNOPSIS
#
#    MST_BOOST_BASE([MINIMUM VERSION])
#
#  DESCRIPTION
#
#    Test for the boost library C++ headers.  First it uses pkg-config
#    looking for a boost_base package; if that isn't found, it uses
#    the AX_BOOST_BASE macro
#
#    This macro dies if it can't find the boost headers
AC_DEFUN([MST_BOOST_BASE],
[
PKG_CHECK_EXISTS([boost_base],
		 [
		   boost_lib_version_req='m4_ifblank([$1],[],[>= $1])'
		   PKG_CHECK_MODULES([BOOST], [boost_base $boost_lib_version_req],
		    		      [ AC_SUBST([BOOST_CPPFLAGS],[$BOOST_CFLAGS])
				       	AC_SUBST([BOOST_LDFLAGS],[$BOOST_LIBS])
                                      ])
		  ],
		  [ AX_BOOST_BASE([$1],
		                  [],
		                  [ AC_MSG_ERROR( [unable to find boost libraries]) ]
		                 )
                  ])
])


# MST_BOOST_LIB
#---------------
#
#  SYNOPSIS
#
#    MST_BOOST_LIB([MINIMUM VERSION],[lib])
#
#  DESCRIPTION
#
#    Test for compiled boost libraries.  First it uses pkg-config
#    looking for a boost_base package; if that isn't found, it uses
#    the AX_BOOST_BASE to set BOOST_LIBS and sees if it can find them there.
#
#    This macro dies if it can't find the libraries
AC_DEFUN([MST_BOOST_LIB],
[
MST_BOOST_BASE([$1],[$2])
PKG_CHECK_EXISTS([boost_[$2]],
		[
		  boost_lib_version_req='m4_ifblank([$1],[],[>= $1])'
		  PKG_CHECK_MODULES([BOOST_$2], [boost_$2 $boost_lib_version_req],
		 	            [ AC_SUBST([BOOST_CPPFLAGS],["$BOOST_CPPFLAGS $BOOST_$2_CFLAGS"])
				      AC_SUBST([BOOST_LDFLAGS],["$BOOST_LDFLAGS $BOOST_$2_LIBS"])
                                    ])
		],
		[
		AC_MSG_ERROR([Unable to find boost $2 library])
		])
])
